pub struct IncomingEvent<Payload = Vec<u8>, Params = Vec<u8>> {
pub payload: Payload,
pub params: Params,
pub user: String,
}Fields
payload: Payloadparams: Paramsuser: StringTrait Implementations
Sourceimpl<Payload: Clone, Params: Clone> Clone for IncomingEvent<Payload, Params>
impl<Payload: Clone, Params: Clone> Clone for IncomingEvent<Payload, Params>
Sourcefn clone(&self) -> IncomingEvent<Payload, Params>
fn clone(&self) -> IncomingEvent<Payload, Params>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Payload, Params> Decode for IncomingEvent<Payload, Params>
impl<Payload, Params> Decode for IncomingEvent<Payload, Params>
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<Payload, Params> Encode for IncomingEvent<Payload, Params>
impl<Payload, Params> Encode for IncomingEvent<Payload, Params>
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl<Payload, Params> EncodeLike for IncomingEvent<Payload, Params>